Learn R Programming

aspi (version 0.2.0)

diplostomum_lenses: Numbers of Diplostomum metacercariae recorded from the lenses of the eyes of each of 50 ruffe.

Description

A dataset containing the numbers of Diplostomum metacercariae recovered from the lenses of the eyes of each of 50 ruffe, Gymnocephalus cernuus from Llyn Tegid, a mesotrophic lake in north Wales.

Usage

diplostomum_lenses

Arguments

Format

A data frame with 50 rows and 2 variables (row names are host IDs):