Learn R Programming

aspi (version 0.2.0)

simulated_left_bias_homogeneous_proportions: Simulated data for showing left bias with homogeneous proportions

Description

Simulated data for 10 hosts, providing an example of bilateral asymmetry with left bias and a similar left:right ratio in all hosts.

Usage

simulated_left_bias_homogeneous_proportions

Arguments

Format

A data frame with 10 rows and 2 variables: